@@ -14,7 +14,7 @@ from collections import Counter
 from copy import deepcopy
 from datetime import datetime
 from functools import lru_cache, partial
-from typing import Match, Optional, Pattern, Tuple, Counter as Counter_Type
+from typing import Match, Optional, Pattern, Tuple, Union, Counter as Counter_Type
 
 from lxml.html import HtmlElement, tostring  # type: ignore
 
@@ -81,14 +81,19 @@ def logstring(element: HtmlElement) -> str:
 
 
 DATE_ATTRIBUTES = {
+    "analyticsattributes.articledate",
     "article.created",
     "article_date_original",
+    "article:post_date",
     "article.published",
+    "article:published",
+    "article:published_date",
     "article:published_time",
     "article:publicationdate",
     "bt:pubdate",
     "citation_date",
     "citation_publication_date",
+    "content_create_date",
     "created",
     "cxenseparse:recs:publishtime",
     "date",
@@ -103,6 +108,7 @@ DATE_ATTRIBUTES = {
     "dc.date.created",
     "dc.date.issued",
     "dc.date.publication",
+    "dcsext.articlefirstpublished",
     "dcterms.created",
     "dcterms.date",
     "dcterms.issued",
@@ -110,32 +116,68 @@ DATE_ATTRIBUTES = {
     "dc:date",
     "displaydate",
     "doc_date",
+    "field-name-post-date",
     "gentime",
+    "mediator_published_time",
+    "meta",  # too loose?
     # Open Graph: https://opengraphprotocol.org/
-    "og:published_time",
+    "og:article:published",
     "og:article:published_time",
+    "og:datepublished",
+    "og:pubdate",
+    "og:publish_date",
+    "og:published_time",
+    "og:question:published_time",
     "originalpublicationdate",
     "parsely-pub-date",
+    "pdate",
+    "ptime",
     "pubdate",
     "publishdate",
     "publish_date",
+    "publish_time",
+    "publish-date",
     "published-date",
+    "published_date",
+    "published_time",
+    "publisheddate",
     "publication_date",
+    "rbpubdate",
+    "release_date",
     "rnews:datepublished",
     "sailthru.date",
     "shareaholic:article_published_time",
     "timestamp",
+    "twt-published-at",
+    "video:release_date",
+    "vr:published_time",
+}
+
+
+NAME_MODIFIED = {
+    "lastdate",
+    "lastmod",
+    "lastmodified",
+    "last-modified",
+    "modified",
+    "utime",
 }
 
 
 PROPERTY_MODIFIED = {
+    "article:modified",
+    "article:modified_date",
     "article:modified_time",
+    "article:post_modified",
+    "bt:moddate",
     "datemodified",
     "dc.modified",
     "dcterms.modified",
     "lastmodified",
     "modified_time",
+    "modificationdate",
     "og:article:modified_time",
+    "og:modified_time",
     "og:updated_time",
     "release_date",
     "revision_date",
@@ -143,15 +185,13 @@ PROPERTY_MODIFIED = {
 }
 
 
-NON_DIGITS_REGEX = re.compile(r"\D+$")
-GER_STRIP_REGEX = re.compile(r"^am ")
-
-LAST_MODIFIED = {"lastmodified", "last-modified"}
 ITEMPROP_ATTRS_ORIGINAL = {"datecreated", "datepublished", "pubyear"}
 ITEMPROP_ATTRS_MODIFIED = {"datemodified", "dateupdate"}
 ITEMPROP_ATTRS = ITEMPROP_ATTRS_ORIGINAL.union(ITEMPROP_ATTRS_MODIFIED)
 CLASS_ATTRS = {"date-published", "published", "time published"}
 
+NON_DIGITS_REGEX = re.compile(r"\D+$")
+
 
 def examine_date_elements(
     tree: HtmlElement,
@@ -169,29 +209,27 @@ def examine_date_elements(
     attempt = None
     for elem in elements:
         # trim
-        text = " ".join(elem.text_content().split()).strip()
+        text = elem.text_content().strip()
         # simple length heuristic
         if len(text) > 6:  # could be 8 or 9
             # shorten and try the beginning of the string
             # trim non-digits at the end of the string
-            toexamine = NON_DIGITS_REGEX.sub("", text[:MAX_TEXT_SIZE])
+            text = NON_DIGITS_REGEX.sub("", text[:MAX_TEXT_SIZE])
             LOGGER.debug(
                 "analyzing (HTML): %s",
-                " ".join(
-                    tostring(elem, pretty_print=False, encoding="unicode").split()
-                ).strip()[:100],
+                " ".join(logstring(elem).split())[:100],
             )
             attempt = try_date_expr(
-                toexamine, outputformat, extensive_search, min_date, max_date
+                text, outputformat, extensive_search, min_date, max_date
             )
             if attempt is not None:
                 break
         # try link title (Blogspot)
-        title_attr = elem.get("title")
+        title_attr = elem.get("title", "").strip()
         if title_attr is not None and len(title_attr) > 0:
-            toexamine = NON_DIGITS_REGEX.sub("", title_attr[:MAX_TEXT_SIZE])
+            title_attr = NON_DIGITS_REGEX.sub("", title_attr[:MAX_TEXT_SIZE])
             attempt = try_date_expr(
-                toexamine, outputformat, extensive_search, min_date, max_date
+                title_attr, outputformat, extensive_search, min_date, max_date
             )
             if attempt is not None:
                 break
@@ -225,11 +263,11 @@ def examine_header(
         one (e.g. last modified, updated time)
     :type original_date: boolean
     :param min_date:
-        Set the earliest acceptable date manually (YYYY-MM-DD format)
-    :type min_date: string
+        Set the earliest acceptable date manually (ISO 8601 YMD format)
+    :type min_date: datetime
     :param max_date:
-        Set the latest acceptable date manually (YYYY-MM-DD format)
-    :type max_date: string
+        Set the latest acceptable date manually (ISO 8601 YMD format)
+    :type max_date: datetime
     :return: Returns a valid date expression as a string, or None
 
     """
@@ -244,10 +282,31 @@ def examine_header(
     # loop through all meta elements
     for elem in tree.iterfind(".//meta"):
         # safeguard
-        if not elem.attrib:  # len(elem.attrib) < 1:
+        if not elem.attrib or (
+            not "content" in elem.attrib and not "datetime" in elem.attrib
+        ):
             continue
+        # name attribute, most frequent
+        if "name" in elem.attrib:
+            attribute = elem.get("name").lower()
+            # url
+            if attribute == "og:url":
+                reserve = extract_url_date(
+                    elem.get("content"), outputformat, min_date, max_date
+                )
+            # date
+            elif attribute in DATE_ATTRIBUTES:
+                LOGGER.debug("examining meta name: %s", logstring(elem))
+                headerdate = tryfunc(elem.get("content"))
+            # modified
+            elif attribute in NAME_MODIFIED:
+                LOGGER.debug("examining meta name: %s", logstring(elem))
+                if not original_date:
+                    headerdate = tryfunc(elem.get("content"))
+                else:
+                    reserve = tryfunc(elem.get("content"))
         # property attribute
-        if "property" in elem.attrib and "content" in elem.attrib:
+        elif "property" in elem.attrib:
             attribute = elem.get("property").lower()
             # original date or modified date: override published_time
             if (original_date and attribute in DATE_ATTRIBUTES) or (
@@ -256,37 +315,13 @@ def examine_header(
             ):
                 LOGGER.debug("examining meta property: %s", logstring(elem))
                 headerdate = tryfunc(elem.get("content"))
-        elif "name" in elem.attrib and "content" in elem.attrib:
-            # url
-            if elem.get("name").lower() == "og:url":
-                headerdate = extract_url_date(
-                    elem.get("content"), outputformat, min_date, max_date
-                )
-            # date
-            elif elem.get("name").lower() in DATE_ATTRIBUTES:
-                LOGGER.debug("examining meta name: %s", logstring(elem))
-                headerdate = tryfunc(elem.get("content"))
-            # modified
-            elif elem.get("name").lower() in LAST_MODIFIED:
-                LOGGER.debug("examining meta name: %s", logstring(elem))
-                if original_date is False:
-                    headerdate = tryfunc(elem.get("content"))
-                else:
-                    reserve = tryfunc(elem.get("content"))
-        elif "pubdate" in elem.attrib:
-            if elem.get("pubdate").lower() == "pubdate":
-                LOGGER.debug("examining meta pubdate: %s", logstring(elem))
-                headerdate = tryfunc(elem.get("content"))
+        # itemprop
         elif "itemprop" in elem.attrib:
             attribute = elem.get("itemprop").lower()
             # original: store / updated: override date
             if attribute in ITEMPROP_ATTRS:
-                attempt = None
                 LOGGER.debug("examining meta itemprop: %s", logstring(elem))
-                if "datetime" in elem.attrib:
-                    attempt = tryfunc(elem.get("datetime"))
-                elif "content" in elem.attrib:
-                    attempt = tryfunc(elem.get("content"))
+                attempt = tryfunc(elem.get("datetime") or elem.get("content"))
                 # store value
                 if attempt is not None:
                     if (attribute in ITEMPROP_ATTRS_ORIGINAL and original_date) or (
@@ -308,6 +343,11 @@ def examine_header(
                         is True
                     ):
                         reserve = attempt
+        # pubdate, relatively rare
+        elif "pubdate" in elem.attrib:
+            if elem.get("pubdate").lower() == "pubdate":
+                LOGGER.debug("examining meta pubdate: %s", logstring(elem))
+                headerdate = tryfunc(elem.get("content"))
         # http-equiv, rare
         elif "http-equiv" in elem.attrib:
             attribute = elem.get("http-equiv").lower()
@@ -319,7 +359,7 @@ def examine_header(
                     reserve = tryfunc(elem.get("content"))
             elif attribute == "last-modified":
                 LOGGER.debug("examining meta http-equiv: %s", logstring(elem))
-                if original_date is False:
+                if not original_date:
                     headerdate = tryfunc(elem.get("content"))
                 else:
                     reserve = tryfunc(elem.get("content"))
@@ -458,7 +498,7 @@ def examine_abbr_elements(
                 elif not original_date and candidate > reference:
                     reference = candidate
             # class
-            if "class" in elem.attrib and elem.get("class") in CLASS_ATTRS:
+            elif elem.get("class") in CLASS_ATTRS:
                 # other attributes
                 if "title" in elem.attrib:
                     trytext = elem.get("title")
@@ -484,12 +524,11 @@ def examine_abbr_elements(
                         if reference > 0:
                             break
                 # dates, not times of the day
-                if elem.text and len(elem.text) > 10:
-                    trytext = GER_STRIP_REGEX.sub("", elem.text)
-                    LOGGER.debug("abbr published found: %s", trytext)
+                elif elem.text and len(elem.text) > 10:
+                    LOGGER.debug("abbr published found: %s", elem.text)
                     reference = compare_reference(
                         reference,
-                        trytext,
+                        elem.text,
                         outputformat,
                         extensive_search,
                         original_date,
@@ -529,23 +568,31 @@ def examine_time_elements(
             # go for datetime
             if "datetime" in elem.attrib and len(elem.get("datetime")) > 6:
                 # shortcut: time pubdate
-                if "pubdate" in elem.attrib and elem.get("pubdate") == "pubdate":
-                    if original_date:
-                        shortcut_flag = True
-                    LOGGER.debug("time pubdate found: %s", elem.get("datetime"))
-                # first choice: entry-date + datetime attribute
+                if (
+                    "pubdate" in elem.attrib
+                    and elem.get("pubdate") == "pubdate"
+                    and original_date
+                ):
+                    shortcut_flag = True
+                    LOGGER.debug(
+                        "shortcut for time pubdate found: %s", elem.get("datetime")
+                    )
+                # shortcuts: class attribute
                 elif "class" in elem.attrib:
-                    if elem.get("class").startswith("entry-date") or elem.get(
-                        "class"
-                    ).startswith("entry-time"):
-                        # shortcut
-                        if original_date:
-                            shortcut_flag = True
-                        LOGGER.debug("time/datetime found: %s", elem.get("datetime"))
-                    # updated time
-                    elif elem.get("class") == "updated" and not original_date:
+                    if original_date and (
+                        elem.get("class").startswith("entry-date")
+                        or elem.get("class").startswith("entry-time")
+                    ):
+                        shortcut_flag = True
                         LOGGER.debug(
-                            "updated time/datetime found: %s", elem.get("datetime")
+                            "shortcut for time/datetime found: %s", elem.get("datetime")
+                        )
+                    # updated time
+                    elif not original_date and elem.get("class") == "updated":
+                        shortcut_flag = True
+                        LOGGER.debug(
+                            "shortcut for updated time/datetime found: %s",
+                            elem.get("datetime"),
                         )
                 # datetime attribute
                 else:
@@ -571,11 +618,9 @@ def examine_time_elements(
                         min_date,
                         max_date,
                     )
-                    if reference > 0:
-                        break
             # bare text in element
             elif elem.text is not None and len(elem.text) > 6:
-                LOGGER.debug("time/datetime found: %s", elem.text)
+                LOGGER.debug("time/datetime found in text: %s", elem.text)
                 reference = compare_reference(
                     reference,
                     elem.text,
@@ -628,6 +673,12 @@ def search_page(
         Look for original date (e.g. publication date) instead of most recent
         one (e.g. last modified, updated time)
     :type original_date: boolean
+    :param min_date:
+        Set the earliest acceptable date manually (ISO 8601 YMD format)
+    :type min_date: datetime
+    :param max_date:
+        Set the latest acceptable date manually (ISO 8601 YMD format)
+    :type max_date: datetime
     :return: Returns a valid date expression as a string, or None
 
     """
@@ -896,8 +947,8 @@ def find_date(
     outputformat: str = "%Y-%m-%d",
     url: Optional[str] = None,
     verbose: bool = False,
-    min_date: Optional[datetime] = None,
-    max_date: Optional[datetime] = None,
+    min_date: Optional[Union[datetime, str]] = None,
+    max_date: Optional[Union[datetime, str]] = None,
     deferred_url_extractor: bool = False,
 ) -> Optional[str]:
     """
@@ -926,11 +977,11 @@ def find_date(
         Set verbosity level for debugging
     :type verbose: boolean
     :param min_date:
-        Set the earliest acceptable date manually (YYYY-MM-DD format)
-    :type min_date: string
+        Set the earliest acceptable date manually (ISO 8601 YMD format)
+    :type min_date: datetime, string
     :param max_date:
-        Set the latest acceptable date manually (YYYY-MM-DD format)
-    :type max_date: string
+        Set the latest acceptable date manually (ISO 8601 YMD format)
+    :type max_date: datetime, string
     :param deferred_url_extractor:
         Use url extractor as backup only to prioritize full expressions,
         e.g. of the type `%Y-%m-%d %H:%M:%S`
@@ -942,30 +993,31 @@ def find_date(
     if verbose:
         logging.basicConfig(level=logging.DEBUG)
     tree = load_html(htmlobject)
-    # unclear what this line is for and it impedes type checking:
-    # find_date.extensive_search = extensive_search
-    min_date, max_date = get_min_date(min_date), get_max_date(max_date)
 
-    # safety
+    # safeguards
     if tree is None:
         return None
     if outputformat != "%Y-%m-%d" and not output_format_validator(outputformat):
         return None
 
+    # define time boundaries
+    min_date, max_date = get_min_date(min_date), get_max_date(max_date)
+    # unclear what this line is for and it impedes type checking:
+    # find_date.extensive_search = extensive_search
+
     # URL
+    url_result = None
     if url is None:
         # probe for canonical links
-        for elem in tree.iterfind('.//link[@rel="canonical"]'):
-            url = elem.get("href")
-            if url is not None:
-                # break out of the loop
-                break
+        urlelem = tree.find('.//link[@rel="canonical"]')
+        if urlelem is not None:
+            url = urlelem.get("href")
 
     # direct processing of URL info
-    if not deferred_url_extractor and url is not None:
-        dateresult = extract_url_date(url, outputformat, min_date, max_date)
-        if dateresult is not None:
-            return dateresult
+    if url is not None:
+        url_result = extract_url_date(url, outputformat, min_date, max_date)
+        if url_result is not None and not deferred_url_extractor:
+            return url_result
 
     # first, try header
     header_result = examine_header(
@@ -980,10 +1032,8 @@ def find_date(
         return json_result
 
     # deferred processing of URL info (may be moved even further down if necessary)
-    if url is not None and deferred_url_extractor:
-        dateresult = extract_url_date(url, outputformat, min_date, max_date)
-        if dateresult is not None:
-            return dateresult
+    if deferred_url_extractor and url_result is not None:
+        return url_result
 
     # try abbr elements
     abbr_result = examine_abbr_elements(
