@@ -12,7 +12,7 @@ import re
 
 from datetime import datetime
 from functools import lru_cache
-from typing import List, Optional, Pattern, Tuple
+from typing import List, Optional, Tuple
 
 # coverage for date parsing
 from dateparser import DateDataParser  # type: ignore  # third-party, slow
@@ -22,13 +22,6 @@ from dateutil.parser import parse as dateutil_parse
 
 from lxml.html import HtmlElement  # type: ignore
 
-try:
-    datetime.fromisoformat  # type: ignore[attr-defined]
-except AttributeError:  # Python 3.6
-    from backports.datetime_fromisoformat import MonkeyPatch  # type: ignore
-
-    MonkeyPatch.patch_fromisoformat()
-
 # own
 from .settings import CACHE_SIZE
 from .validators import convert_date, date_validator
@@ -37,20 +30,21 @@ from .validators import convert_date, date_validator
 LOGGER = logging.getLogger(__name__)
 
 EXTERNAL_PARSER = DateDataParser(
+    languages=None,
+    locales=None,
+    region=None,
     settings={
-        #    'DATE_ORDER': 'DMY',
-        "PREFER_DATES_FROM": "past",
-        #    'PREFER_DAY_OF_MONTH': 'first',
-        #    'PREFER_LOCALE_DATE_ORDER': True,
-        "STRICT_PARSING": True,
+        "NORMALIZE": True,  # False may be faster
         "PARSERS": [
             p
             for p in default_parsers
             if p not in ("no-spaces-time", "relative-time", "timestamp")
         ],
+        "PREFER_DATES_FROM": "past",
+        "PREFER_LOCALE_DATE_ORDER": True,
         "RETURN_AS_TIMEZONE_AWARE": False,
-        #    'NORMALIZE': False,
-    }
+        "STRICT_PARSING": True,
+    },
 )
 
 
@@ -244,16 +238,11 @@ DISCARD_PATTERNS = re.compile(
 # \b\d{5}\s  # postal codes
 
 # use of regex module for speed?
-EN_PATTERNS = re.compile(
-    r'(?:date[^0-9"]{,20}|updated|published) *?(?:in)? *?:? *?([0-9]{1,4})[./]([0-9]{1,2})[./]([0-9]{2,4})',
-    re.I,
-)
-DE_PATTERNS = re.compile(
-    r"(?:Datum|Stand): ?([0-9]{1,2})\.([0-9]{1,2})\.([0-9]{2,4})", re.I
-)
-TR_PATTERNS = re.compile(
+TEXT_PATTERNS = re.compile(
+    r'(?:date[^0-9"]{,20}|updated|published) *?(?:in)? *?:? *?([0-9]{1,4})[./]([0-9]{1,2})[./]([0-9]{2,4})|'  # EN
+    r"(?:Datum|Stand): ?([0-9]{1,2})\.([0-9]{1,2})\.([0-9]{2,4})|"  # DE
     r"(?:güncellen?me|yayı(?:m|n)lan?ma) *?(?:tarihi)? *?:? *?([0-9]{1,2})[./]([0-9]{1,2})[./]([0-9]{2,4})|"
-    r"([0-9]{1,2})[./]([0-9]{1,2})[./]([0-9]{2,4}) *?(?:'de|'da|'te|'ta|’de|’da|’te|’ta|tarihinde) *(?:güncellendi|yayı(?:m|n)landı)",
+    r"([0-9]{1,2})[./]([0-9]{1,2})[./]([0-9]{2,4}) *?(?:'de|'da|'te|'ta|’de|’da|’te|’ta|tarihinde) *(?:güncellendi|yayı(?:m|n)landı)",  # TR
     re.I,
 )
 
@@ -381,9 +370,8 @@ def regex_parse(string: str) -> Optional[datetime]:
         dateobject = datetime(year, month, day)
     except ValueError:
         return None
-    else:
-        LOGGER.debug("multilingual text found: %s", dateobject)
-        return dateobject
+    LOGGER.debug("multilingual text found: %s", dateobject)
+    return dateobject
 
 
 def custom_parse(
@@ -534,7 +522,7 @@ def try_date_expr(
 ) -> Optional[str]:
     """Use a series of heuristics and rules to parse a potential date expression"""
     # trim
-    string = " ".join(string[:MAX_TEXT_SIZE].split()).strip()
+    string = " ".join(string.strip()[:MAX_TEXT_SIZE].split())
 
     # formal constraint: 4 to 18 digits
     if not string or not 4 <= sum(map(str.isdigit, string)) <= 18:
@@ -616,60 +604,37 @@ def timestamp_search(
     return None
 
 
-def extract_idiosyncrasy(
-    idiosyncrasy: Pattern[str],
-    htmlstring: str,
-    outputformat: str,
-    min_date: datetime,
-    max_date: datetime,
-) -> Optional[str]:
-    """Look for a precise pattern throughout the web page"""
-    candidate = None
-    match = idiosyncrasy.search(htmlstring)
-    parts = [0, 1, 2, 3] if match and match[3] else []  # because len(None) has no len
-    try:
-        parts = [0, 4, 5, 6] if match and match[6] else parts
-    except IndexError:
-        LOGGER.debug("index error in idiosyncrasies: %s", match[0])  # type: ignore[index]
-    if match and parts:
-        if match[parts[1]] is not None and len(match[parts[1]]) == 4:
-            candidate = datetime(
-                int(match[parts[1]]), int(match[parts[2]]), int(match[parts[3]])
-            )
-        elif len(match[parts[3]]) in (2, 4):
-            # DD/MM/YY
-            day, month = try_swap_values(int(match[parts[1]]), int(match[parts[2]]))
-            year = correct_year(int(match[parts[3]]))
-            try:
-                candidate = datetime(year, month, day)
-            except ValueError:
-                LOGGER.debug("value error in idiosyncrasies: %s", match[0])
-    if (
-        date_validator(candidate, "%Y-%m-%d", earliest=min_date, latest=max_date)
-        is True
-    ):
-        LOGGER.debug("idiosyncratic pattern found: %s", match[0])  # type: ignore[index]
-        return candidate.strftime(outputformat)  # type: ignore
-    return None
-
-
 def idiosyncrasies_search(
     htmlstring: str, outputformat: str, min_date: datetime, max_date: datetime
 ) -> Optional[str]:
     """Look for author-written dates throughout the web page"""
-    result = None
-    # DE
-    result = extract_idiosyncrasy(
-        DE_PATTERNS, htmlstring, outputformat, min_date, max_date
-    )
-    # EN
-    if result is None:
-        result = extract_idiosyncrasy(
-            EN_PATTERNS, htmlstring, outputformat, min_date, max_date
-        )
-    # TR
-    if result is None:
-        result = extract_idiosyncrasy(
-            TR_PATTERNS, htmlstring, outputformat, min_date, max_date
-        )
-    return result
+    # EN+DE+TR
+    match = TEXT_PATTERNS.search(htmlstring)
+    if not match:
+        return None
+
+    parts = list(filter(None, match.groups()))
+    if len(parts) != 3:
+        return None
+
+    candidate = None
+
+    if len(parts[0]) == 4:
+        candidate = datetime(int(parts[0]), int(parts[1]), int(parts[2]))
+    elif len(parts[2]) in (2, 4):
+        # DD/MM/YY
+        day, month = try_swap_values(int(parts[0]), int(parts[1]))
+        year = correct_year(int(parts[2]))
+        try:
+            candidate = datetime(year, month, day)
+        except ValueError:
+            LOGGER.debug("value error in idiosyncrasies: %s", match[0])
+
+    if (
+        date_validator(candidate, "%Y-%m-%d", earliest=min_date, latest=max_date)
+        is True
+    ):
+        LOGGER.debug("idiosyncratic pattern found: %s", match[0])
+        return candidate.strftime(outputformat)  # type: ignore[union-attr]
+
+    return None
