@@ -15,19 +15,19 @@ from functools import lru_cache
 from time import mktime
 from typing import Match, Optional, Pattern, Union, Counter as Counter_Type
 
-from .settings import CACHE_SIZE, LATEST_POSSIBLE, MIN_DATE
+from .settings import CACHE_SIZE, MIN_DATE
 
 
 LOGGER = logging.getLogger(__name__)
-LOGGER.debug("date settings: %s %s", MIN_DATE, LATEST_POSSIBLE)
+LOGGER.debug("minimum date setting: %s", MIN_DATE)
 
 
 @lru_cache(maxsize=CACHE_SIZE)
 def date_validator(
     date_input: Optional[Union[datetime, str]],
     outputformat: str,
-    earliest: datetime = MIN_DATE,
-    latest: datetime = LATEST_POSSIBLE,
+    earliest: datetime,
+    latest: datetime,
 ) -> bool:
     """Validate a string w.r.t. the chosen outputformat and basic heuristics"""
     # safety check
@@ -61,6 +61,7 @@ def date_validator(
     return False
 
 
+@lru_cache(maxsize=16)
 def output_format_validator(outputformat: str) -> bool:
     """Validate the output format in the settings"""
     # test with date object
@@ -71,11 +72,10 @@ def output_format_validator(outputformat: str) -> bool:
     except (NameError, TypeError, ValueError) as err:
         LOGGER.error("wrong output format or type: %s %s", outputformat, err)
         return False
-    else:
-        # test in abstracto
-        if not isinstance(outputformat, str) or "%" not in outputformat:
-            LOGGER.error("malformed output format: %s", outputformat)
-            return False
+    # test in abstracto
+    if not isinstance(outputformat, str) or "%" not in outputformat:
+        LOGGER.error("malformed output format: %s", outputformat)
+        return False
     return True
 
 
@@ -84,8 +84,8 @@ def plausible_year_filter(
     *,
     pattern: Pattern[str],
     yearpat: Pattern[str],
-    earliest: datetime = MIN_DATE,
-    latest: datetime = LATEST_POSSIBLE,
+    earliest: datetime,
+    latest: datetime,
     incomplete: bool = False,
 ) -> Counter_Type[str]:
     """Filter the date patterns to find plausible years only"""
@@ -194,31 +194,25 @@ def check_extracted_reference(
     return None
 
 
+def check_date_input(
+    date_object: Optional[Union[datetime, str]], default: datetime
+) -> datetime:
+    "Check if the input is a usable datetime or ISO date string, return default otherwise"
+    if isinstance(date_object, datetime):
+        return date_object
+    if isinstance(date_object, str):
+        try:
+            return datetime.fromisoformat(date_object)  # type: ignore
+        except ValueError:
+            LOGGER.warning("invalid datetime string: %s", date_object)
+    return default  # no input or error thrown
+
+
 def get_min_date(min_date: Optional[Union[datetime, str]]) -> datetime:
     """Validates the minimum date and/or defaults to earliest plausible date"""
-    if min_date is not None and isinstance(min_date, str):
-        try:
-            # internal conversion from Y-M-D format
-            min_date = datetime(
-                int(min_date[:4]), int(min_date[5:7]), int(min_date[8:10])
-            )
-        except ValueError:
-            min_date = MIN_DATE
-    else:
-        min_date = MIN_DATE
-    return min_date
+    return check_date_input(min_date, MIN_DATE)
 
 
 def get_max_date(max_date: Optional[Union[datetime, str]]) -> datetime:
     """Validates the maximum date and/or defaults to latest plausible date"""
-    if max_date is not None and isinstance(max_date, str):
-        try:
-            # internal conversion from Y-M-D format
-            max_date = datetime(
-                int(max_date[:4]), int(max_date[5:7]), int(max_date[8:10])
-            )
-        except ValueError:
-            max_date = LATEST_POSSIBLE
-    else:
-        max_date = LATEST_POSSIBLE
-    return max_date
+    return check_date_input(max_date, datetime.now())
